@@ -42,7 +42,7 @@ APPLET_NAME = 'firewall-applet'
 DATADIR = '/usr/share/' + DAEMON_NAME
 CONFIG_GLADE_NAME = CONFIG_NAME + '.glade'
 COPYRIGHT = '(C) 2010-2016 Red Hat, Inc.'
-VERSION = '0.4.4'
+VERSION = '0.4.4.2'
 AUTHORS = [
     "Thomas Woerner <twoerner@redhat.com>",
     "Jiri Popelka <jpopelka@redhat.com>",
@@ -101,6 +101,9 @@ COMMANDS = {
     "eb":           "/usr/bin/ebtables",
     "eb-restore":   "/usr/bin/ebtables-restore",
     "ipset":        "/usr/bin/ipset",
+    "modinfo":      "/usr/bin/modinfo",
+    "modprobe":     "/usr/bin/modprobe",
+    "rmmod":        "/usr/bin/rmmod",
 }
 
 LOG_DENIED_VALUES = [ "all", "unicast", "broadcast", "multicast", "off" ]
