@@ -676,7 +676,12 @@ def zone_reader(filename, path):
     parser.setContentHandler(handler)
     name = "%s/%s" % (path, filename)
     with open(name, "r") as f:
-        parser.parse(f)
+        try:
+            parser.parse(f)
+        except sax.SAXParseException as msg:
+            raise FirewallError(errors.INVALID_ZONE,
+                                "not a valid zone file: %s" % \
+                                msg.getException())
     del handler
     del parser
     if PY2:
