@@ -32,10 +32,10 @@ from firewall import config
 from firewall.dbus_utils import dbus_to_python, \
     dbus_introspection_prepare_properties, \
     dbus_introspection_add_properties
-from firewall.core.fw import Firewall
 from firewall.core.io.icmptype import IcmpType
 from firewall.core.logger import log
-from firewall.server.decorators import *
+from firewall.server.decorators import handle_exceptions, \
+    dbus_handle_exceptions, dbus_service_method
 from firewall import errors
 from firewall.errors import FirewallError
 
@@ -54,15 +54,15 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     """ Use PK_ACTION_INFO as a default """
 
     @handle_exceptions
-    def __init__(self, parent, conf, icmptype, id, *args, **kwargs):
+    def __init__(self, parent, conf, icmptype, item_id, *args, **kwargs):
         super(FirewallDConfigIcmpType, self).__init__(*args, **kwargs)
         self.parent = parent
         self.config = conf
         self.obj = icmptype
-        self.id = id
+        self.item_id = item_id
         self.busname = args[0]
         self.path = args[1]
-        self._log_prefix = "config.icmptype.%d" % self.id
+        self._log_prefix = "config.icmptype.%d" % self.item_id
         dbus_introspection_prepare_properties(
             self, config.dbus.DBUS_INTERFACE_CONFIG_ICMPTYPE)
 
@@ -94,12 +94,12 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
             raise dbus.exceptions.DBusException(
                 "org.freedesktop.DBus.Error.AccessDenied: "
                 "Property '%s' isn't exported (or may not exist)" % \
-                    property_name)
+                property_name)
 
     @dbus_service_method(dbus.PROPERTIES_IFACE, in_signature='ss',
                          out_signature='v')
     @dbus_handle_exceptions
-    def Get(self, interface_name, property_name, sender=None):
+    def Get(self, interface_name, property_name, sender=None): # pylint: disable=W0613
         # get a property
         interface_name = dbus_to_python(interface_name, str)
         property_name = dbus_to_python(property_name, str)
@@ -116,7 +116,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @dbus_service_method(dbus.PROPERTIES_IFACE, in_signature='s',
                          out_signature='a{sv}')
     @dbus_handle_exceptions
-    def GetAll(self, interface_name, sender=None):
+    def GetAll(self, interface_name, sender=None): # pylint: disable=W0613
         interface_name = dbus_to_python(interface_name, str)
         log.debug1("%s.GetAll('%s')", self._log_prefix, interface_name)
 
@@ -162,7 +162,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @slip.dbus.polkit.require_auth(config.dbus.PK_ACTION_INFO)
     @dbus_service_method(dbus.INTROSPECTABLE_IFACE, out_signature='s')
     @dbus_handle_exceptions
-    def Introspect(self, sender=None):
+    def Introspect(self, sender=None): # pylint: disable=W0613
         log.debug2("%s.Introspect()", self._log_prefix)
 
         data = super(FirewallDConfigIcmpType, self).Introspect(
@@ -176,7 +176,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @dbus_service_method(config.dbus.DBUS_INTERFACE_CONFIG_ICMPTYPE,
                          out_signature=IcmpType.DBUS_SIGNATURE)
     @dbus_handle_exceptions
-    def getSettings(self, sender=None):
+    def getSettings(self, sender=None): # pylint: disable=W0613
         """get settings for icmptype
         """
         log.debug1("%s.getSettings()", self._log_prefix)
@@ -253,7 +253,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @dbus_service_method(config.dbus.DBUS_INTERFACE_CONFIG_ICMPTYPE,
                          out_signature='s')
     @dbus_handle_exceptions
-    def getVersion(self, sender=None):
+    def getVersion(self, sender=None): # pylint: disable=W0613
         log.debug1("%s.getVersion()", self._log_prefix)
         return self.getSettings()[0]
 
@@ -273,7 +273,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @dbus_service_method(config.dbus.DBUS_INTERFACE_CONFIG_ICMPTYPE,
                          out_signature='s')
     @dbus_handle_exceptions
-    def getShort(self, sender=None):
+    def getShort(self, sender=None): # pylint: disable=W0613
         log.debug1("%s.getShort()", self._log_prefix)
         return self.getSettings()[1]
 
@@ -293,7 +293,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @dbus_service_method(config.dbus.DBUS_INTERFACE_CONFIG_ICMPTYPE,
                          out_signature='s')
     @dbus_handle_exceptions
-    def getDescription(self, sender=None):
+    def getDescription(self, sender=None): # pylint: disable=W0613
         log.debug1("%s.getDescription()", self._log_prefix)
         return self.getSettings()[2]
 
@@ -314,7 +314,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @dbus_service_method(config.dbus.DBUS_INTERFACE_CONFIG_ICMPTYPE,
                          out_signature='as')
     @dbus_handle_exceptions
-    def getDestinations(self, sender=None):
+    def getDestinations(self, sender=None): # pylint: disable=W0613
         log.debug1("%s.getDestinations()", self._log_prefix)
         return sorted(self.getSettings()[3])
 
@@ -366,7 +366,7 @@ class FirewallDConfigIcmpType(slip.dbus.service.Object):
     @dbus_service_method(config.dbus.DBUS_INTERFACE_CONFIG_ICMPTYPE,
                          in_signature='s', out_signature='b')
     @dbus_handle_exceptions
-    def queryDestination(self, destination, sender=None):
+    def queryDestination(self, destination, sender=None): # pylint: disable=W0613
         destination = dbus_to_python(destination, str)
         log.debug1("%s.queryDestination('%s')", self._log_prefix,
                    destination)
